@@ -12,9 +12,9 @@ async def send_message_and_wait_for_completion(
     company_id: str,
     assistant_id: str,
     text: str,
-    tool_choices: List[str] = None,
+    tool_choices: List[str] | None = None,
     scope_rules: dict | None = None,
-    chat_id: str = None,
+    chat_id: str | None = None,
     poll_interval: float = 1.0,
     max_wait: float = 60.0,
     stop_condition: Literal["stoppedStreamingAt", "completedAt"] = "stoppedStreamingAt",
@@ -49,10 +49,10 @@ async def send_message_and_wait_for_completion(
 
     max_attempts = int(max_wait // poll_interval)
     for _ in range(max_attempts):
-        answer = Space.get_latest_message(user_id, company_id, chat_id)
+        answer = await Space.get_latest_message_async(user_id, company_id, chat_id)
         if answer.get(stop_condition) is not None:
             try:
-                user_message = Message.retrieve(
+                user_message = await Message.retrieve_async(
                     user_id, company_id, message_id, chatId=chat_id
                 )
                 debug_info = user_message.get("debugInfo")
@@ -152,7 +152,7 @@ async def wait_for_ingestion_completion(
     user_id: str,
     company_id: str,
     content_id: str,
-    chat_id: str = None,
+    chat_id: str | None = None,
     poll_interval: float = 1.0,
     max_wait: float = 60.0,
 ):
